/******/ (() => { // webpackBootstrap
/******/ 	"use strict";
/******/ 	var __webpack_modules__ = ({

/***/ 989:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {


var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", ({ value: true }));
const fs_1 = __importDefault(__webpack_require__(147));
const path_1 = __importDefault(__webpack_require__(17));
const source_map_1 = __webpack_require__(471);
const electron_1 = __webpack_require__(298);
const menuTemplate_1 = __importDefault(__webpack_require__(575));
process.on('unhandledRejection', (reason, promise) => {
    if (reason instanceof Error)
        console.error(`Unhandled Rejection ${reason.name}: ${reason.message}:\n${reason.stack}`);
    else
        console.error('Unhandled Rejection: ${reason}');
});
const LOG = {
    debug: 0,
    info: 1,
    warn: 2,
    error: 3
}[process.env.LOG] || Number(process.env.LOG) || 1;
// We don't want multiple copies of our application running.
if (!electron_1.app.requestSingleInstanceLock()) {
    electron_1.app.focus();
    // The second-instance handler will be fired automatically.
    electron_1.app.exit();
    process.exit();
}
// Chromium sandboxing requires an suid helper binary to be present, but we want users to be able to install Firo
// Client without root. Therefore, we need to disable sandboxing. This shouldn't be a security risk since we don't have
// any untrusted code anyway.
electron_1.app.commandLine.appendSwitch('--no-sandbox');
// Shared memory can't be used if the client is being run over SSH, and Chromium has a bug where it fails to
// automatically detect the situation. Therefore, if we detect we're being run over SSH, we will tell it to not use
// shared memory ourselves.
if (process.env.SSH_CLIENT) {
    electron_1.app.commandLine.appendSwitch('--no-xshm');
}
// Register us as the handler for firo:// links. Actual handling of them is done in main.js.
if (!electron_1.app.isDefaultProtocolClient('firo')) {
    console.info("Setting Firo Client as the default handler for firo:// links...");
    // This can sometimes fail, in which case it will not throw but will print an error to stderr.
    electron_1.app.setAsDefaultProtocolClient('firo');
}
electron_1.app.once('ready', async () => {
    // Set the application menu. This is required for keyboard shortcuts (including copy+paste) to work correctly.
    const appMenu = electron_1.Menu.buildFromTemplate(menuTemplate_1.default);
    electron_1.Menu.setApplicationMenu(appMenu);
    // The window will be shown by the renderer process when firod is connected.
    const ourWindow = new electron_1.BrowserWindow({
        frame: process.platform !== 'darwin',
        useContentSize: true,
        titleBarStyle: 'hiddenInset',
        height: 800,
        width: 1400,
        minWidth: 1250,
        minHeight: 800,
        webPreferences: {
            nodeIntegration: true,
            contextIsolation: false
        }
    });
    const sourceMaps = {};
    const logPath = path_1.default.join(electron_1.app.getPath('userData'), 'firo-client.log');
    // This will overwrite the old log so as to reduce clutter.
    const logFile = await fs_1.default.promises.open(logPath, 'w');
    ourWindow.webContents.on('console-message', async (event, level, msg, mangledLine, sourceId) => {
        if (level < LOG)
            return;
        let map;
        let sourceMapFile = undefined;
        if (sourceMaps[sourceId]) {
            map = sourceMaps[sourceId];
        }
        else if (sourceMapFile) {
            let rawMapData;
            try {
                rawMapData = (await fs_1.default.promises.readFile(sourceMapFile)).toString();
            }
            catch (e) { }
            if (rawMapData) {
                try {
                    let rawMap = JSON.parse(rawMapData);
                    map = new source_map_1.SourceMapConsumer(rawMap);
                    sourceMaps[sourceId] = map;
                }
                catch (e) {
                    console.info(e);
                }
            }
        }
        let location;
        if (map) {
            const { source, line } = map.originalPositionFor({ line: mangledLine, column: 0 });
            location = `${source}:${line}`;
        }
        else {
            location = `${sourceId}:${mangledLine}`;
        }
        const levelStrs = {
            0: 'debug',
            1: 'info',
            2: 'warn',
            3: 'error',
        };
        const levelStr = levelStrs[level] || 'info';
        const output = `${levelStr}: ${msg} (${location})`;
        console[levelStr](output);
        await logFile.write(output + "\n");
    });
    // Fire the shutdown-requested listener in renderer/main.js when the user tries to close us.
    ourWindow.on('close', (event) => {
        event.preventDefault();
        ourWindow.webContents.send('shutdown-requested');
    });
    // Removing old listeners on navigation is ecessary to prevent warnings when we quit while hot reloading is enabled.
    ourWindow.webContents.on("will-navigate", () => {
        ourWindow.webContents.removeAllListeners('shutdown-requested');
    });
    electron_1.ipcMain.handle('exit', () => electron_1.app.exit());
    electron_1.ipcMain.handle('get-path', (ev, name) => name == 'app' ? electron_1.app.getAppPath() : electron_1.app.getPath(name));
    electron_1.ipcMain.handle('select-directory', async (ev, options) => {
        const r = await electron_1.dialog.showOpenDialog(ourWindow, options);
        if (r.canceled)
            return;
        return r.filePaths;
    });
    electron_1.app.on('open-url', async (ev, msg) => {
        ev.preventDefault();
        ourWindow.webContents.emit('open-url', msg);
    });
    // Stop new alt-clicks from opening new BrowserWindows.
    //
    // NOTE: This MUST be done in the main process to work.
    //       cf. https://github.com/electron/electron/issues/2770#issuecomment-140065309
    //
    // FIXME: alt-clicking on a router link will still cause the link to be highlighted even though no other action is
    //        taken.
    ourWindow.webContents.setWindowOpenHandler(() => ({ action: 'deny' }));
    if (process.env.FIRO_CLIENT_TEST) {
        const indexDotHtml = path_1.default.join(electron_1.app.getAppPath(), 'index.html');
        console.info(`Loading test environment at ${indexDotHtml}...`);
        await ourWindow.loadFile(indexDotHtml);
    }
    else if (false) {}
    else if (true) {
        const indexDotHtml = path_1.default.join(electron_1.app.getAppPath(), '..', 'app.asar.unpacked', 'dist', 'electron', 'index.html');
        console.info(`Loading production environment at ${indexDotHtml}...`);
        await ourWindow.loadFile(indexDotHtml);
    }
    else {}
});


/***/ }),

/***/ 575:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ([
    ...(process.platform === 'darwin' ? [{
        label: 'Firo Client',
        submenu: [
            {role: 'about', label: 'About Firo Client'},
            {role: 'hide', label: 'Hide Firo Client'},
            {role: 'hideothers'},
            {role: 'unhide'},
            {type: 'separator'},
            {role: 'quit', label: 'Quit Firo Client'}
        ]
    }] : []),

    {
        label: 'Edit',
        submenu: [
            {role: 'undo'},
            {role: 'redo'},
            {role: 'cut'},
            {role: 'copy'},
            {role: 'paste'},
            {role: 'pasteandmatchstyle'},
            {role: 'delete'},
            {role: 'selectall'}
        ]
    },

    {
        label: 'View',
        submenu: [
            {role: 'reload'},
            {role: 'forcereload'},
            {role: 'toggledevtools'},
            {role: 'resetzoom'},
            {role: 'zoomin'},
            {role: 'zoomout'},
            {role: 'togglefullscreen'}
        ]
    },

    {
        role: 'window',
        submenu: [
            {role: 'minimize'},
            {role: 'close'},
            ...(process.platform === 'darwin' ? [
                {role: 'zoom'},
                {type: 'separator'},
                {role: 'front'}
            ] : [])
        ]
    }
]);


/***/ }),

/***/ 471:
/***/ ((module) => {

module.exports = require("source-map");

/***/ }),

/***/ 298:
/***/ ((module) => {

module.exports = require("electron");

/***/ }),

/***/ 147:
/***/ ((module) => {

module.exports = require("fs");

/***/ }),

/***/ 17:
/***/ ((module) => {

module.exports = require("path");

/***/ })

/******/ 	});
/************************************************************************/
/******/ 	// The module cache
/******/ 	var __webpack_module_cache__ = {};
/******/ 	
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/ 		// Check if module is in cache
/******/ 		var cachedModule = __webpack_module_cache__[moduleId];
/******/ 		if (cachedModule !== undefined) {
/******/ 			return cachedModule.exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = __webpack_module_cache__[moduleId] = {
/******/ 			// no module.id needed
/******/ 			// no module.loaded needed
/******/ 			exports: {}
/******/ 		};
/******/ 	
/******/ 		// Execute the module function
/******/ 		__webpack_modules__[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/ 	
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/ 	
/************************************************************************/
/******/ 	/* webpack/runtime/define property getters */
/******/ 	(() => {
/******/ 		// define getter functions for harmony exports
/******/ 		__webpack_require__.d = (exports, definition) => {
/******/ 			for(var key in definition) {
/******/ 				if(__webpack_require__.o(definition, key) && !__webpack_require__.o(exports, key)) {
/******/ 					Object.defineProperty(exports, key, { enumerable: true, get: definition[key] });
/******/ 				}
/******/ 			}
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/hasOwnProperty shorthand */
/******/ 	(() => {
/******/ 		__webpack_require__.o = (obj, prop) => (Object.prototype.hasOwnProperty.call(obj, prop))
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/make namespace object */
/******/ 	(() => {
/******/ 		// define __esModule on exports
/******/ 		__webpack_require__.r = (exports) => {
/******/ 			if(typeof Symbol !== 'undefined' && Symbol.toStringTag) {
/******/ 				Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });
/******/ 			}
/******/ 			Object.defineProperty(exports, '__esModule', { value: true });
/******/ 		};
/******/ 	})();
/******/ 	
/************************************************************************/
/******/ 	
/******/ 	// startup
/******/ 	// Load entry module and return exports
/******/ 	// This entry module is referenced by other modules so it can't be inlined
/******/ 	var __webpack_exports__ = __webpack_require__(989);
/******/ 	module.exports = __webpack_exports__;
/******/ 	
/******/ })()
;